@@ -2,6 +2,7 @@ import numpy
 import xarray
 import matplotlib.pyplot as plt
 from osgeo import gdal
+from matplotlib import colors
 
 class objearth():
     def __init__(self):
@@ -257,4 +258,44 @@ class objearth():
         d = numpy.sqrt(x*x+y*y)
         sigma, mu = 0.5, 1.0
         g = numpy.exp(-( (d-mu)**2 / ( 2.0 * sigma**2 ) ) )
-        return g
\ No newline at end of file
+        return g
+    
+    @staticmethod
+    def bluecmap():
+        RGB6 = (0.1, 0.1, 0.1)
+        RGB5 = (0.        , 0.31372549, 0.45098039)
+        RGB4 = (0.0627451 , 0.49019608, 0.6745098 )
+        RGB3 = (0.09411765, 0.60392157, 0.82745098)
+        RGB2 = (0.11764706, 0.73333333, 0.84313725)
+        RGB1 = (0.44313725, 0.78039216, 0.9254902 )
+        RGB0 = (0.99, 0.99, 0.99 )
+        cdict = {
+        'red':  ((1  / 6 * 0, RGB0[0]  ,RGB0[0]),
+                (1  / 6 * 1, RGB1[0]  ,RGB1[0]),
+                (1  / 6 * 2, RGB2[0]  ,RGB2[0]),
+                (1  / 6 * 3, RGB3[0]  ,RGB3[0]),
+                (1  / 6 * 4, RGB4[0]  ,RGB4[0]),
+                (1  / 6 * 5, RGB5[0]  ,RGB5[0]),
+                (1  / 6 * 6, RGB6[0]  ,RGB6[0])
+                ),
+
+        'green':((1  / 6 * 0, RGB0[1]    , RGB0[1]),
+                (1  / 6 * 1, RGB1[1]    , RGB1[1]),
+                (1  / 6 * 2, RGB2[1]    , RGB2[1]),
+                (1  / 6 * 3, RGB3[1]    , RGB3[1]),
+                (1  / 6 * 4, RGB4[1]    , RGB4[1]),
+                (1  / 6 * 5, RGB5[1]    , RGB5[1]),
+                (1  / 6 * 6, RGB6[1]    , RGB6[1])
+                ),
+
+        'blue': ((1  / 6 * 0, RGB0[2]    , RGB0[2]),
+                (1  / 6 * 1, RGB1[2]    , RGB1[2]),
+                (1  / 6 * 2, RGB2[2]    , RGB2[2]),
+                (1  / 6 * 3, RGB3[2]    , RGB3[2]),
+                (1  / 6 * 4, RGB4[2]    , RGB4[2]),
+                (1  / 6 * 5, RGB5[2]    , RGB5[2]),
+                (1  / 6 * 6, RGB6[2]    , RGB6[2])
+                ),
+        }
+        nc = colors.LinearSegmentedColormap('modify_cmap',segmentdata=cdict)
+        return nc
\ No newline at end of file
